@@ -776,9 +776,10 @@ static void get_attrs_param (lua_State *L, char *attrs[]) {
 		luaL_checkstack(L, n, NULL);
 		for (i = 0; i < n; i++) {
 			lua_rawgeti (L, -1, i+1); /* push table element */
-			if (lua_isstring (L, -1))
+			if (lua_isstring (L, -1)) {
 				attrs[i] = (char *)lua_tostring (L, -1);
-			else {
+				lua_pop(L, 1);
+			} else {
 				luaL_error (L, LUALDAP_PREFIX"invalid value #%d", i+1);
 			}
 		}
@@ -1061,7 +1062,7 @@ static void set_info (lua_State *L) {
 	lua_setfield (L, -2, "_COPYRIGHT");
 	lua_pushliteral (L, "LuaLDAP is a simple interface from Lua to an LDAP client");
 	lua_setfield (L, -2, "_DESCRIPTION");
-	lua_pushliteral (L, "LuaLDAP 1.3.0");
+	lua_pushliteral (L, "LuaLDAP 1.3.1");
 	lua_setfield (L, -2, "_VERSION");
 }
 
