@@ -444,6 +444,15 @@ local function count (tab)
 	return counter
 end
 
+local function count_attrs (tab)
+	local counter = 0
+	for dn, entry in LD:search (tab) do
+		for k,v in pairs(entry) do
+			counter = counter + 1
+		end
+	end
+	return counter
+end
 
 ---------------------------------------------------------------------
 -- checking even more advanced search operation.
@@ -469,6 +478,15 @@ describe("even more advanced search operation", function()
 			end
 		end
 	end)
+	it("attrs as string works", function()
+		assert.is_same(1, count { base = BASE, scope = "subtree", filter = filter, attrs = "mail", })
+	end)
+	it("attrs as table works", function()
+		local attrs = {"name", "organization", "not_in_ldap"}
+		local tab = { base = BASE, scope = "subtree", filter = filter, attrs = attrs }
+		assert.is_same(1, count(tab))
+		assert.is_same(4, count_attrs(tab))
+	end)
 	it("reusing search objects is possible", function()
 		local iter = assert.is_not_nil(LD:search { base = BASE, scope = "base", })
 		assert.is_calleable(iter)
